##  Bulk Linking Application Fact Sheets
In the reference catalog, you can preview recommendations for multiple fact sheets, establish links, ignore certain items, and modify existing linked items, all in one location.
To link multiple fact sheets at once, do the following:
  1. On the navigation bar, click More > Reference Catalog > Application Linking. On the catalog page that appears, fact sheets are arranged into different tabs based on whether they're unlinked, ignored, or linked.
  2. On the Unlinked tab, select a fact sheet, select a relevant catalog item to link to, then click Link.
You can bulk link fact sheets for which recommended items are provided. To do that, select fact sheets, then click Link Selected.


![Linking Fact Sheets to Catalog Items in Bulk](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b7e3a7a44101498f9838fbf12c45e_LowRes.png)
Linking Fact Sheets to Catalog Items in Bulk
The Confidence column on the right provides an intelligent recommendation indicating the match level between the fact sheet and the catalog item. If you want to focus on fact sheets with very high or high confidence levels, you can use the Filter by confidence option located in the upper-left corner.
The confidence level score is calculated based on the matches between the fact sheet display name and the catalog item name. The confidence levels are categorized as follows:
  * Very high (100)
  * High (96–99)
  * Other, displayed without a text label (below 96)


By expanding each row, you can view a summary of the fact sheet and details of the corresponding catalog item recommendation. If the recommendation doesn't align with your needs, use the search field to find a specific item to link to. You can link, preview, or ignore individual fact sheets in each row.
